// package: supervisor
// file: control.proto

var control_pb = require("./control_pb");
var grpc = require("@improbable-eng/grpc-web").grpc;

var ControlService = (function () {
  function ControlService() {}
  ControlService.serviceName = "supervisor.ControlService";
  return ControlService;
}());

ControlService.ExposePort = {
  methodName: "ExposePort",
  service: ControlService,
  requestStream: false,
  responseStream: false,
  requestType: control_pb.ExposePortRequest,
  responseType: control_pb.ExposePortResponse
};

ControlService.CreateSSHKeyPair = {
  methodName: "CreateSSHKeyPair",
  service: ControlService,
  requestStream: false,
  responseStream: false,
  requestType: control_pb.CreateSSHKeyPairRequest,
  responseType: control_pb.CreateSSHKeyPairResponse
};

ControlService.CreateDebugEnv = {
  methodName: "CreateDebugEnv",
  service: ControlService,
  requestStream: false,
  responseStream: false,
  requestType: control_pb.CreateDebugEnvRequest,
  responseType: control_pb.CreateDebugEnvResponse
};

exports.ControlService = ControlService;

function ControlServiceClient(serviceHost, options) {
  this.serviceHost = serviceHost;
  this.options = options || {};
}

ControlServiceClient.prototype.exposePort = function exposePort(requestMessage, metadata, callback) {
  if (arguments.length === 2) {
    callback = arguments[1];
  }
  var client = grpc.unary(ControlService.ExposePort, {
    request: requestMessage,
    host: this.serviceHost,
    metadata: metadata,
    transport: this.options.transport,
    debug: this.options.debug,
    onEnd: function (response) {
      if (callback) {
        if (response.status !== grpc.Code.OK) {
          var err = new Error(response.statusMessage);
          err.code = response.status;
          err.metadata = response.trailers;
          callback(err, null);
        } else {
          callback(null, response.message);
        }
      }
    }
  });
  return {
    cancel: function () {
      callback = null;
      client.close();
    }
  };
};

ControlServiceClient.prototype.createSSHKeyPair = function createSSHKeyPair(requestMessage, metadata, callback) {
  if (arguments.length === 2) {
    callback = arguments[1];
  }
  var client = grpc.unary(ControlService.CreateSSHKeyPair, {
    request: requestMessage,
    host: this.serviceHost,
    metadata: metadata,
    transport: this.options.transport,
    debug: this.options.debug,
    onEnd: function (response) {
      if (callback) {
        if (response.status !== grpc.Code.OK) {
          var err = new Error(response.statusMessage);
          err.code = response.status;
          err.metadata = response.trailers;
          callback(err, null);
        } else {
          callback(null, response.message);
        }
      }
    }
  });
  return {
    cancel: function () {
      callback = null;
      client.close();
    }
  };
};

ControlServiceClient.prototype.createDebugEnv = function createDebugEnv(requestMessage, metadata, callback) {
  if (arguments.length === 2) {
    callback = arguments[1];
  }
  var client = grpc.unary(ControlService.CreateDebugEnv, {
    request: requestMessage,
    host: this.serviceHost,
    metadata: metadata,
    transport: this.options.transport,
    debug: this.options.debug,
    onEnd: function (response) {
      if (callback) {
        if (response.status !== grpc.Code.OK) {
          var err = new Error(response.statusMessage);
          err.code = response.status;
          err.metadata = response.trailers;
          callback(err, null);
        } else {
          callback(null, response.message);
        }
      }
    }
  });
  return {
    cancel: function () {
      callback = null;
      client.close();
    }
  };
};

exports.ControlServiceClient = ControlServiceClient;

