// package: supervisor
// file: port.proto

import * as port_pb from "./port_pb";
import {grpc} from "@improbable-eng/grpc-web";

type PortServiceTunnel = {
  readonly methodName: string;
  readonly service: typeof PortService;
  readonly requestStream: false;
  readonly responseStream: false;
  readonly requestType: typeof port_pb.TunnelPortRequest;
  readonly responseType: typeof port_pb.TunnelPortResponse;
};

type PortServiceCloseTunnel = {
  readonly methodName: string;
  readonly service: typeof PortService;
  readonly requestStream: false;
  readonly responseStream: false;
  readonly requestType: typeof port_pb.CloseTunnelRequest;
  readonly responseType: typeof port_pb.CloseTunnelResponse;
};

type PortServiceEstablishTunnel = {
  readonly methodName: string;
  readonly service: typeof PortService;
  readonly requestStream: true;
  readonly responseStream: true;
  readonly requestType: typeof port_pb.EstablishTunnelRequest;
  readonly responseType: typeof port_pb.EstablishTunnelResponse;
};

type PortServiceAutoTunnel = {
  readonly methodName: string;
  readonly service: typeof PortService;
  readonly requestStream: false;
  readonly responseStream: false;
  readonly requestType: typeof port_pb.AutoTunnelRequest;
  readonly responseType: typeof port_pb.AutoTunnelResponse;
};

type PortServiceRetryAutoExpose = {
  readonly methodName: string;
  readonly service: typeof PortService;
  readonly requestStream: false;
  readonly responseStream: false;
  readonly requestType: typeof port_pb.RetryAutoExposeRequest;
  readonly responseType: typeof port_pb.RetryAutoExposeResponse;
};

export class PortService {
  static readonly serviceName: string;
  static readonly Tunnel: PortServiceTunnel;
  static readonly CloseTunnel: PortServiceCloseTunnel;
  static readonly EstablishTunnel: PortServiceEstablishTunnel;
  static readonly AutoTunnel: PortServiceAutoTunnel;
  static readonly RetryAutoExpose: PortServiceRetryAutoExpose;
}

export type ServiceError = { message: string, code: number; metadata: grpc.Metadata }
export type Status = { details: string, code: number; metadata: grpc.Metadata }

interface UnaryResponse {
  cancel(): void;
}
interface ResponseStream<T> {
  cancel(): void;
  on(type: 'data', handler: (message: T) => void): ResponseStream<T>;
  on(type: 'end', handler: (status?: Status) => void): ResponseStream<T>;
  on(type: 'status', handler: (status: Status) => void): ResponseStream<T>;
}
interface RequestStream<T> {
  write(message: T): RequestStream<T>;
  end(): void;
  cancel(): void;
  on(type: 'end', handler: (status?: Status) => void): RequestStream<T>;
  on(type: 'status', handler: (status: Status) => void): RequestStream<T>;
}
interface BidirectionalStream<ReqT, ResT> {
  write(message: ReqT): BidirectionalStream<ReqT, ResT>;
  end(): void;
  cancel(): void;
  on(type: 'data', handler: (message: ResT) => void): BidirectionalStream<ReqT, ResT>;
  on(type: 'end', handler: (status?: Status) => void): BidirectionalStream<ReqT, ResT>;
  on(type: 'status', handler: (status: Status) => void): BidirectionalStream<ReqT, ResT>;
}

export class PortServiceClient {
  readonly serviceHost: string;

  constructor(serviceHost: string, options?: grpc.RpcOptions);
  tunnel(
    requestMessage: port_pb.TunnelPortRequest,
    metadata: grpc.Metadata,
    callback: (error: ServiceError|null, responseMessage: port_pb.TunnelPortResponse|null) => void
  ): UnaryResponse;
  tunnel(
    requestMessage: port_pb.TunnelPortRequest,
    callback: (error: ServiceError|null, responseMessage: port_pb.TunnelPortResponse|null) => void
  ): UnaryResponse;
  closeTunnel(
    requestMessage: port_pb.CloseTunnelRequest,
    metadata: grpc.Metadata,
    callback: (error: ServiceError|null, responseMessage: port_pb.CloseTunnelResponse|null) => void
  ): UnaryResponse;
  closeTunnel(
    requestMessage: port_pb.CloseTunnelRequest,
    callback: (error: ServiceError|null, responseMessage: port_pb.CloseTunnelResponse|null) => void
  ): UnaryResponse;
  establishTunnel(metadata?: grpc.Metadata): BidirectionalStream<port_pb.EstablishTunnelRequest, port_pb.EstablishTunnelResponse>;
  autoTunnel(
    requestMessage: port_pb.AutoTunnelRequest,
    metadata: grpc.Metadata,
    callback: (error: ServiceError|null, responseMessage: port_pb.AutoTunnelResponse|null) => void
  ): UnaryResponse;
  autoTunnel(
    requestMessage: port_pb.AutoTunnelRequest,
    callback: (error: ServiceError|null, responseMessage: port_pb.AutoTunnelResponse|null) => void
  ): UnaryResponse;
  retryAutoExpose(
    requestMessage: port_pb.RetryAutoExposeRequest,
    metadata: grpc.Metadata,
    callback: (error: ServiceError|null, responseMessage: port_pb.RetryAutoExposeResponse|null) => void
  ): UnaryResponse;
  retryAutoExpose(
    requestMessage: port_pb.RetryAutoExposeRequest,
    callback: (error: ServiceError|null, responseMessage: port_pb.RetryAutoExposeResponse|null) => void
  ): UnaryResponse;
}

