// package: supervisor
// file: status.proto

var status_pb = require("./status_pb");
var grpc = require("@improbable-eng/grpc-web").grpc;

var StatusService = (function () {
  function StatusService() {}
  StatusService.serviceName = "supervisor.StatusService";
  return StatusService;
}());

StatusService.SupervisorStatus = {
  methodName: "SupervisorStatus",
  service: StatusService,
  requestStream: false,
  responseStream: false,
  requestType: status_pb.SupervisorStatusRequest,
  responseType: status_pb.SupervisorStatusResponse
};

StatusService.IDEStatus = {
  methodName: "IDEStatus",
  service: StatusService,
  requestStream: false,
  responseStream: false,
  requestType: status_pb.IDEStatusRequest,
  responseType: status_pb.IDEStatusResponse
};

StatusService.ContentStatus = {
  methodName: "ContentStatus",
  service: StatusService,
  requestStream: false,
  responseStream: false,
  requestType: status_pb.ContentStatusRequest,
  responseType: status_pb.ContentStatusResponse
};

StatusService.BackupStatus = {
  methodName: "BackupStatus",
  service: StatusService,
  requestStream: false,
  responseStream: false,
  requestType: status_pb.BackupStatusRequest,
  responseType: status_pb.BackupStatusResponse
};

StatusService.PortsStatus = {
  methodName: "PortsStatus",
  service: StatusService,
  requestStream: false,
  responseStream: true,
  requestType: status_pb.PortsStatusRequest,
  responseType: status_pb.PortsStatusResponse
};

StatusService.TasksStatus = {
  methodName: "TasksStatus",
  service: StatusService,
  requestStream: false,
  responseStream: true,
  requestType: status_pb.TasksStatusRequest,
  responseType: status_pb.TasksStatusResponse
};

StatusService.ResourcesStatus = {
  methodName: "ResourcesStatus",
  service: StatusService,
  requestStream: false,
  responseStream: false,
  requestType: status_pb.ResourcesStatuRequest,
  responseType: status_pb.ResourcesStatusResponse
};

exports.StatusService = StatusService;

function StatusServiceClient(serviceHost, options) {
  this.serviceHost = serviceHost;
  this.options = options || {};
}

StatusServiceClient.prototype.supervisorStatus = function supervisorStatus(requestMessage, metadata, callback) {
  if (arguments.length === 2) {
    callback = arguments[1];
  }
  var client = grpc.unary(StatusService.SupervisorStatus, {
    request: requestMessage,
    host: this.serviceHost,
    metadata: metadata,
    transport: this.options.transport,
    debug: this.options.debug,
    onEnd: function (response) {
      if (callback) {
        if (response.status !== grpc.Code.OK) {
          var err = new Error(response.statusMessage);
          err.code = response.status;
          err.metadata = response.trailers;
          callback(err, null);
        } else {
          callback(null, response.message);
        }
      }
    }
  });
  return {
    cancel: function () {
      callback = null;
      client.close();
    }
  };
};

StatusServiceClient.prototype.iDEStatus = function iDEStatus(requestMessage, metadata, callback) {
  if (arguments.length === 2) {
    callback = arguments[1];
  }
  var client = grpc.unary(StatusService.IDEStatus, {
    request: requestMessage,
    host: this.serviceHost,
    metadata: metadata,
    transport: this.options.transport,
    debug: this.options.debug,
    onEnd: function (response) {
      if (callback) {
        if (response.status !== grpc.Code.OK) {
          var err = new Error(response.statusMessage);
          err.code = response.status;
          err.metadata = response.trailers;
          callback(err, null);
        } else {
          callback(null, response.message);
        }
      }
    }
  });
  return {
    cancel: function () {
      callback = null;
      client.close();
    }
  };
};

StatusServiceClient.prototype.contentStatus = function contentStatus(requestMessage, metadata, callback) {
  if (arguments.length === 2) {
    callback = arguments[1];
  }
  var client = grpc.unary(StatusService.ContentStatus, {
    request: requestMessage,
    host: this.serviceHost,
    metadata: metadata,
    transport: this.options.transport,
    debug: this.options.debug,
    onEnd: function (response) {
      if (callback) {
        if (response.status !== grpc.Code.OK) {
          var err = new Error(response.statusMessage);
          err.code = response.status;
          err.metadata = response.trailers;
          callback(err, null);
        } else {
          callback(null, response.message);
        }
      }
    }
  });
  return {
    cancel: function () {
      callback = null;
      client.close();
    }
  };
};

StatusServiceClient.prototype.backupStatus = function backupStatus(requestMessage, metadata, callback) {
  if (arguments.length === 2) {
    callback = arguments[1];
  }
  var client = grpc.unary(StatusService.BackupStatus, {
    request: requestMessage,
    host: this.serviceHost,
    metadata: metadata,
    transport: this.options.transport,
    debug: this.options.debug,
    onEnd: function (response) {
      if (callback) {
        if (response.status !== grpc.Code.OK) {
          var err = new Error(response.statusMessage);
          err.code = response.status;
          err.metadata = response.trailers;
          callback(err, null);
        } else {
          callback(null, response.message);
        }
      }
    }
  });
  return {
    cancel: function () {
      callback = null;
      client.close();
    }
  };
};

StatusServiceClient.prototype.portsStatus = function portsStatus(requestMessage, metadata) {
  var listeners = {
    data: [],
    end: [],
    status: []
  };
  var client = grpc.invoke(StatusService.PortsStatus, {
    request: requestMessage,
    host: this.serviceHost,
    metadata: metadata,
    transport: this.options.transport,
    debug: this.options.debug,
    onMessage: function (responseMessage) {
      listeners.data.forEach(function (handler) {
        handler(responseMessage);
      });
    },
    onEnd: function (status, statusMessage, trailers) {
      listeners.status.forEach(function (handler) {
        handler({ code: status, details: statusMessage, metadata: trailers });
      });
      listeners.end.forEach(function (handler) {
        handler({ code: status, details: statusMessage, metadata: trailers });
      });
      listeners = null;
    }
  });
  return {
    on: function (type, handler) {
      listeners[type].push(handler);
      return this;
    },
    cancel: function () {
      listeners = null;
      client.close();
    }
  };
};

StatusServiceClient.prototype.tasksStatus = function tasksStatus(requestMessage, metadata) {
  var listeners = {
    data: [],
    end: [],
    status: []
  };
  var client = grpc.invoke(StatusService.TasksStatus, {
    request: requestMessage,
    host: this.serviceHost,
    metadata: metadata,
    transport: this.options.transport,
    debug: this.options.debug,
    onMessage: function (responseMessage) {
      listeners.data.forEach(function (handler) {
        handler(responseMessage);
      });
    },
    onEnd: function (status, statusMessage, trailers) {
      listeners.status.forEach(function (handler) {
        handler({ code: status, details: statusMessage, metadata: trailers });
      });
      listeners.end.forEach(function (handler) {
        handler({ code: status, details: statusMessage, metadata: trailers });
      });
      listeners = null;
    }
  });
  return {
    on: function (type, handler) {
      listeners[type].push(handler);
      return this;
    },
    cancel: function () {
      listeners = null;
      client.close();
    }
  };
};

StatusServiceClient.prototype.resourcesStatus = function resourcesStatus(requestMessage, metadata, callback) {
  if (arguments.length === 2) {
    callback = arguments[1];
  }
  var client = grpc.unary(StatusService.ResourcesStatus, {
    request: requestMessage,
    host: this.serviceHost,
    metadata: metadata,
    transport: this.options.transport,
    debug: this.options.debug,
    onEnd: function (response) {
      if (callback) {
        if (response.status !== grpc.Code.OK) {
          var err = new Error(response.statusMessage);
          err.code = response.status;
          err.metadata = response.trailers;
          callback(err, null);
        } else {
          callback(null, response.message);
        }
      }
    }
  });
  return {
    cancel: function () {
      callback = null;
      client.close();
    }
  };
};

exports.StatusServiceClient = StatusServiceClient;

